package com.nicolas.juegosclasicos;

import android.content.Context;
import android.util.AttributeSet;
import android.view.MotionEvent;
import android.view.SurfaceHolder;
import android.view.SurfaceView;
import android.graphics.Canvas;
import android.hardware.Sensor;
import android.hardware.SensorEvent;
import android.hardware.SensorEventListener;
import android.media.MediaPlayer;

public class Pantalla extends SurfaceView implements SurfaceHolder.Callback, SensorEventListener {
	
	protected int width, height, acelerometro, vidas;
	private Vista thread;
	private Nadal nadal;
	private Ladrillo ladrillo;
	private Pelota pelota;
	private boolean jugando;
	private MediaPlayer reproductorAbucheo;

	
	public Pantalla (Context context, AttributeSet attrs) {
		super(context, attrs);
		this.reproductorAbucheo = MediaPlayer.create(context, R.raw.abucheo);
		reproductorAbucheo.setLooping(false);
		getHolder().addCallback(this);
		thread = new Vista(getHolder(), this);
		jugando = false;
		vidas = 3;
		nadal = new Nadal(context);
		ladrillo = new Ladrillo(context);
		pelota = new Pelota(context, nadal, ladrillo);
		setFocusable(true);
	}
	
	@Override
	public void onDraw(Canvas canvas) {
		if (!ladrillo.actualizar(canvas, vidas) && vidas > 0) {
			nadal.actualizar(canvas, acelerometro);
			pelota.actualizar(canvas, jugando);
			if (pelota.getPosicionY() > nadal.getPosicionY() + 10) {
				reproductorAbucheo.start();
				jugando = false;
				vidas --;
			}	
		}
	}
	
	public boolean onTouchEvent(MotionEvent event) {
		jugando = true;
    	return true;
    }

	
	public void surfaceChanged(SurfaceHolder holder, int format, int width, int height) {
		this.width = width;
		this.height = height;
		ladrillo.redimensionarLadrillos(height, width);
		nadal.setPosition(width / 2, height - height / 10, width);
	}

	
	public void surfaceCreated(SurfaceHolder holder) {
		if (thread.getState() == Thread.State.TERMINATED) {
			thread = new Vista(getHolder(), this);
			thread.setRunning(true);
			thread.start();
		} else {
			thread.setRunning(true);
			thread.start();
		}
	}

	
	public void surfaceDestroyed(SurfaceHolder holder) {
		boolean retry = true;
		thread.setRunning(false);
		while (retry) {
			try {
				thread.join();
				retry = false;
			} catch (InterruptedException e) {  }
		}
	}
	
	
	public void onAccuracyChanged(Sensor arg0, int arg1) {
		
	}

	
	public void onSensorChanged(SensorEvent arg0) {
		synchronized(this) {
			if (arg0.sensor.getType() == Sensor.TYPE_ACCELEROMETER) acelerometro = (int)(arg0.values[1] * 6);
		}
	}

}
